# Generated by Django 5.1.1 on 2026-01-28 02:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0002b_deduplicate_display_names'),
    ]

    operations = [
        migrations.AlterField(
            model_name='datasource',
            name='display_name',
            field=models.CharField(default='Datasource 1', max_length=40, unique=True),
        ),
    ]
