# Generated by Django 5.2.12 on 2026-03-09 14:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0007_tablecolumn_primary_key'),
    ]

    operations = [
        migrations.AddField(
            model_name='datasource',
            name='is_global',
            field=models.BooleanField(default=False, help_text='If True, this datasource is accessible by all organisations (read-only).'),
        ),
    ]
