# Generated by Django 5.1.1 on 2026-03-15 05:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('core', '0009_table_is_hidden_table_metadata_updated_at_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='servicetoken',
            name='groups',
            field=models.ManyToManyField(blank=True, help_text='Groups inherited by this token to evaluate GroupTableSelector/GroupColumnSelector', related_name='service_tokens', to='auth.group'),
        ),
    ]
