# Generated by Django 5.1.1 on 2026-01-28 12:34

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0003_alter_datasource_display_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='servicetoken',
            name='organisation',
            field=models.ForeignKey(blank=True, help_text='If set, token can access all datasources in this organisation', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='service_tokens', to='core.coreorganisation'),
        ),
        migrations.AlterField(
            model_name='servicetoken',
            name='datasources',
            field=models.ManyToManyField(blank=True, help_text='If set, overrides org scope with explicit datasource list', related_name='service_tokens', to='core.datasource'),
        ),
    ]
