# Generated by Django 5.1.1 on 2026-03-14 12:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0008_datasource_is_global'),
    ]

    operations = [
        migrations.AddField(
            model_name='table',
            name='is_hidden',
            field=models.BooleanField(default=False, help_text='If True, this table is globally hidden from all API consumers and the AI agent.'),
        ),
        migrations.AddField(
            model_name='table',
            name='metadata_updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='tablecolumn',
            name='is_hidden',
            field=models.BooleanField(default=False, help_text='If True, this column is globally hidden from all API consumers and the AI agent.'),
        ),
        migrations.AddField(
            model_name='tablecolumn',
            name='metadata_updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
    ]
