# Generated by Django 5.1.1 on 2026-02-06 07:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0004_servicetoken_organisation_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='servicetoken',
            name='scopes',
            field=models.JSONField(blank=True, default=list, help_text="List of scopes this token grants. E.g. ['query:read', 'query:execute', 'admin:read']"),
        ),
    ]
