# Generated by Django 5.1.1 on 2026-02-13 10:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0005_servicetoken_scopes'),
    ]

    operations = [
        migrations.AddField(
            model_name='table',
            name='estimated_row_count',
            field=models.BigIntegerField(blank=True, help_text='Approximate row count fetched during metadata sync.', null=True),
        ),
    ]
