{% load static %}
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}TernoDBI - Database Interface Layer{% endblock %}</title>
    <link rel="icon" type="image/png" href="{% static 'terno_dbi/img/logo-icon.png' %}">
    <link
        href="https://fonts.googleapis.com/css2?family=Outfit:wght@400;500;600;700&family=Inter:wght@400;500;600;700&family=JetBrains+Mono:wght@400;500&display=swap"
        rel="stylesheet">
    <link rel="stylesheet" href="{% static 'terno_dbi/css/main.css' %}">
    {% block extra_head %}{% endblock %}
</head>

<body>
    <header>
        <div class="container header-content">
            <a href="/" class="logo">
                <img src="{% static 'terno_dbi/img/logo.png' %}" alt="TernoDBI"
                    style="height: 40px; width: auto; object-fit: contain;">
                <span class="logo-text">TernoDBI</span>
            </a>
            <nav>
                <ul>
                    <li><a href="https://terno-ai.github.io/ternodbi/setup.html" target="_blank">Doc<span
                                class="hide-mobile">umentation</span></a></li>
                    <li><a href="/admin/">Admin</a></li>
                    <li><a href="https://github.com/terno-ai/ternodbi" target="_blank">GitHub</a></li>
                </ul>
            </nav>
        </div>
    </header>

    <main>
        {% block content %}{% endblock %}
    </main>

    <footer>
        <div class="container footer-content">
            <p>&copy; {% now "Y" %} TernoAI Inc. All rights reserved.</p>
            <p>TernoDBI v0.1.0 • Apache 2.0 License</p>
        </div>
    </footer>

    <script src="{% static 'terno_dbi/js/status.js' %}"></script>
    {% block extra_js %}{% endblock %}
</body>

</html>