# Generated by Django 5.1.1 on 2026-03-02 07:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0006_table_estimated_row_count'),
    ]

    operations = [
        migrations.AddField(
            model_name='tablecolumn',
            name='primary_key',
            field=models.BooleanField(default=False),
        ),
    ]
